# coding: utf-8

"""
Module electron_be
==================

This module contains a list of binding energy in eV for electronic levels
of atoms. These data are experimental values taken from the X-Ray data
booklet.

This module is used by msspec to infer kinetic energy values when
they are not specified. For example, to get the Au 4f7/2 binding energy
(remembering that gold atomic number is 79 and that the 4f7/2 level is
n7 in spectroscopic notation...)

.. code-block:: python

    from msspec.data import electron_be
    print(electron_be[79]['n7'])
    84.0


.. seealso::
        X-Ray data booklet
                `Electron binding energies <http://xdb.lbl.gov/>`_ are
                taken from here.

"""


# a database for elements
electron_be = [None for i in range(104)]

electron_be[1]  = {
    'k' : 13.6}
electron_be[2] = {
    'k' : 24.6}
electron_be[3] = {
    'k' : 54.7}
electron_be[4] = {
    'k' : 111.5}
electron_be[5] = {
    'k' : 188.}
electron_be[6] = {
    'k' : 284.2}
electron_be[7] = {
    'k' : 409.9,
    'l1':37.3}
electron_be[8] = {
    'k' : 543.1,
    'l1': 41.6}
electron_be[9] = {
    'k' : 696.7}
electron_be[10] = {
    'k' : 870.2,
    'l1': 48.5,
    'l2': 21.7,
    'l3': 21.6}
electron_be[11] = {
    'k' : 1070.8,
    'l1': 63.5,
    'l2': 30.65,
    'l3': 30.81}
electron_be[12] = {
    'k' : 1303.,
    'l1': 88.7,
    'l2': 49.78,
    'l3': 49.50}
electron_be[13] = {
    'k' : 1559.6,
    'l1': 117.8,
    'l2': 72.95,
    'l3': 72.55}
electron_be[14] = {
    'k' : 1839.,
    'l1': 149.7,
    'l2': 99.82,
    'l3': 99.42}
electron_be[15] = {
    'k' : 2145.5,
    'l1': 189.,
    'l2': 136.,
    'l3': 135.}
electron_be[16] = {
    'k' : 2472.,
    'l1': 230.9,
    'l2': 163.6,
    'l3': 162.5}
electron_be[17] = {
    'k' : 2822.4,
    'l1': 270.,
    'l2': 202.,
    'l3': 200.}
electron_be[18] = {
    'k' : 3205.9,
    'l1': 326.3,
    'l2': 250.6,
    'l3': 248.4,
    'm1': 29.3,
    'm2': 15.9,
    'm3': 15.7}
electron_be[19] = {
    'k' : 3608.4,
    'l1': 378.6,
    'l2': 297.3,
    'l3': 294.6,
    'm1': 34.8,
    'm2': 18.3,
    'm3': 18.3}
electron_be[20] = {
    'k' : 4038.5,
    'l1': 438.4,
    'l2': 349.7,
    'l3': 346.2,
    'm1': 44.3,
    'm2': 25.4,
    'm3': 25.4}
electron_be[21] = {
    'k' : 4492.,
    'l1': 498.,
    'l2': 403.6,
    'l3': 398.7,
    'm1': 51.1,
    'm2': 28.3,
    'm3': 28.3}
electron_be[22] = {
    'k' : 4966.,
    'l1': 560.9,
    'l2': 460.2,
    'l3': 453.8,
    'm1': 58.7,
    'm2': 32.6,
    'm3': 32.6}
electron_be[23] = {
    'k' : 5465.,
    'l1': 626.7,
    'l2': 519.8,
    'l3': 512.1,
    'm1': 66.3,
    'm2': 37.2,
    'm3': 37.2}
electron_be[24] = {
    'k' : 5989.,
    'l1': 696.,
    'l2': 583.8,
    'l3': 574.1,
    'm1': 74.1,
    'm2': 42.2,
    'm3': 42.2}
electron_be[25] = {
    'k' : 6539.,
    'l1': 796.1,
    'l2': 649.9,
    'l3': 638.7,
    'm1': 82.3,
    'm2': 47.2,
    'm3': 47.2}
electron_be[26] = {
    'k' : 7112.,
    'l1': 844.6,
    'l2': 719.9,
    'l3': 706.8,
    'm1': 91.3,
    'm2': 52.7,
    'm3': 52.7}
electron_be[27] = {
    'k' : 7709.,
    'l1': 925.1,
    'l2': 793.2,
    'l3': 778.1,
    'm1': 101.,
    'm2': 58.9,
    'm3': 59.9}
electron_be[28] = {
    'k' : 8333.,
    'l1': 1008.6,
    'l2': 870.,
    'l3': 852.7,
    'm1': 110.8,
    'm2': 68.0,
    'm3': 66.2}
electron_be[29] = {
    'k' : 8979.,
    'l1': 1096.7,
    'l2': 952.3,
    'l3': 932.7,
    'm1': 122.5,
    'm2': 77.3,
    'm3': 75.1}
electron_be[30] = {
    'k' : 9659.,
    'l1': 1196.2,
    'l2': 1044.9,
    'l3': 1021.8,
    'm1': 139.8,
    'm2': 91.4,
    'm3': 88.6,
    'm4': 10.2,
    'm5': 10.1}
electron_be[31] = {
    'k' : 10367.,
    'l1': 1299.,
    'l2': 1143.2,
    'l3': 1116.4,
    'm1': 159.5,
    'm2': 103.5,
    'm3': 100.,
    'm4': 18.7,
    'm5': 18.7}
electron_be[32] = {
    'k' : 11103.,
    'l1': 1414.6,
    'l2': 1248.1,
    'l3': 1217.,
    'm1': 180.1,
    'm2': 124.9,
    'm3': 120.8,
    'm4': 29.8,
    'm5': 29.2}
electron_be[33] = {
    'k' : 11867.,
    'l1': 1527.,
    'l2': 1359.1,
    'l3': 1323.6,
    'm1': 204.7,
    'm2': 146.2,
    'm3': 141.2,
    'm4': 41.7,
    'm5': 41.7}
electron_be[34] = {
    'k' : 12658.,
    'l1': 1652.,
    'l2': 1474.3,
    'l3': 1433.9,
    'm1': 229.6,
    'm2': 166.5,
    'm3': 160.7,
    'm4': 55.5,
    'm5': 54.6}
electron_be[35] = {
    'k' : 13474.,
    'l1': 1782.,
    'l2': 1596.,
    'l3': 1550.,
    'm1': 257.,
    'm2': 189.,
    'm3': 182.,
    'm4': 70.,
    'm5': 69.}
electron_be[36] = {
    'k' : 14326.,
    'l1': 1921.,
    'l2': 1703.9,
    'l3': 1678.4,
    'm1': 292.8,
    'm2': 222.2,
    'm3': 214.4,
    'm4': 95.,
    'm5': 93.8,
    'n1': 27.5,
    'n2': 14.1,
    'n3': 14.1}
electron_be[37] = {
    'k' : 15200.,
    'l1': 2065.,
    'l2': 1864.,
    'l3': 1804.,
    'm1': 326.7,
    'm2': 248.7,
    'm3': 239.1,
    'm4': 113.,
    'm5': 112.,
    'n1': 30.5,
    'n2': 16.3,
    'n3': 15.3}
electron_be[38] = {
    'k' : 16105.,
    'l1': 2216.,
    'l2': 2007.,
    'l3': 1940.,
    'm1': 358.7,
    'm2': 280.3,
    'm3': 270.,
    'm4': 136.,
    'm5': 134.2,
    'n1': 38.9,
    'n2': 21.3,
    'n3': 20.1}
electron_be[39] = {
    'k' : 17038.,
    'l1': 2373.,
    'l2': 2156.,
    'l3': 2080.,
    'm1': 392.,
    'm2': 310.6,
    'm3': 298.8,
    'm4': 157.7,
    'm5': 155.8,
    'n1': 43.8,
    'n2': 24.4,
    'n3': 23.1}

electron_be[40] = {
    'k' : 17998.,
    'l1': 2532.,
    'l2': 2307.,
    'l3': 2223.,
    'm1': 430.3,
    'm2': 343.5,
    'm3': 329.8,
    'm4': 181.1,
    'm5': 178.8,
    'n1': 50.6,
    'n2': 28.5,
    'n3': 27.1}
electron_be[41] = {
    'k' : 18986.,
    'l1': 2698.,
    'l2': 2465.,
    'l3': 2371.,
    'm1': 466.6,
    'm2': 376.1,
    'm3': 360.6,
    'm4': 205.0,
    'm5': 202.3,
    'n1': 56.4,
    'n2': 32.6,
    'n3': 30.8}
electron_be[42] = {
    'k' : 20000.,
    'l1': 2866.,
    'l2': 2625.,
    'l3': 2520.,
    'm1': 506.3,
    'm2': 411.6,
    'm3': 394.,
    'm4': 231.1,
    'm5': 227.9,
    'n1': 63.2,
    'n2': 37.6,
    'n3': 35.5}
electron_be[43] = {
    'k' : 21044.,
    'l1': 3043.,
    'l2': 2793.,
    'l3': 2677.,
    'm1': 544.,
    'm2': 447.6,
    'm3': 417.7,
    'm4': 257.6,
    'm5': 253.9,
    'n1': 69.5,
    'n2': 42.3,
    'n3': 39.9}
electron_be[44] = {
    'k' : 22117.,
    'l1': 3224.,
    'l2': 2967.,
    'l3': 2838.,
    'm1': 586.1,
    'm2': 483.5,
    'm3': 461.4,
    'm4': 284.2,
    'm5': 280.0,
    'n1': 75.0,
    'n2': 46.3,
    'n3': 43.2}
electron_be[45] = {
    'k' : 23220.,
    'l1': 3412.,
    'l2': 3146.,
    'l3': 3004.,
    'm1': 628.1,
    'm2': 521.3,
    'm3': 496.5,
    'm4': 311.9,
    'm5': 307.2,
    'n1': 81.4,
    'n2': 50.5,
    'n3': 47.3}
electron_be[46] = {
    'k' : 24350.,
    'l1': 3604.,
    'l2': 3330.,
    'l3': 3173.,
    'm1': 671.6,
    'm2': 559.9,
    'm3': 532.3,
    'm4': 340.5,
    'm5': 335.2,
    'n1': 87.1,
    'n2': 55.7,
    'n3': 50.9}
electron_be[47] = {
    'k' : 25514.,
    'l1': 3806.,
    'l2': 3524.,
    'l3': 3351.,
    'm1': 719.,
    'm2': 603.8,
    'm3': 573.0,
    'm4': 374.,
    'm5': 368.3,
    'n1': 97.,
    'n2': 63.7,
    'n3': 58.3}

electron_be[48] = {
    'k' : 26711.,
    'l1': 4018.,
    'l2': 3727.,
    'l3': 3538.,
    'm1': 772.,
    'm2': 652.6,
    'm3': 618.4,
    'm4': 411.9,
    'm5': 405.2,
    'n1': 109.8,
    'n2': 63.9,
    'n3': 63.9,
    'n4': 11.7,
    'n5': 10.7}
electron_be[49] = {
    'k' : 27940.,
    'l1': 4238.,
    'l2': 3938.,
    'l3': 3730.,
    'm1': 827.2,
    'm2': 703.2,
    'm3': 665.3,
    'm4': 451.4,
    'm5': 443.9,
    'n1': 122.9,
    'n2': 73.5,
    'n3': 73.5,
    'n4': 17.7,
    'n5': 16.9}
electron_be[50] = {
    'k' : 29200.,
    'l1': 4465.,
    'l2': 4156.,
    'l3': 3929.,
    'm1': 884.7,
    'm2': 756.5,
    'm3': 714.6,
    'm4': 493.2,
    'm5': 484.9,
    'n1': 137.1,
    'n2': 83.6,
    'n3': 83.6,
    'n4': 24.9,
    'n5': 23.9}
electron_be[51] = {
    'k' : 30491.,
    'l1': 4698.,
    'l2': 4380.,
    'l3': 4132.,
    'm1': 946.,
    'm2': 812.7,
    'm3': 766.4,
    'm4': 537.5,
    'm5': 528.2,
    'n1': 153.2,
    'n2': 95.6,
    'n3': 95.6,
    'n4': 33.3,
    'n5': 32.1}
electron_be[52] = {
    'k' : 31814.,
    'l1': 4939.,
    'l2': 4612.,
    'l3': 4341.,
    'm1': 1006.,
    'm2': 870.8,
    'm3': 820.0,
    'm4': 583.4,
    'm5': 573.,
    'n1': 169.4,
    'n2': 103.3,
    'n3': 103.3,
    'n4': 41.9,
    'n5': 40.4}
electron_be[53] = {
    'k' : 33169.,
    'l1': 5188.,
    'l2': 4852.,
    'l3': 4557.,
    'm1': 1072.,
    'm2': 931.,
    'm3': 875.0,
    'm4': 630.8,
    'm5': 619.3,
    'n1': 186.,
    'n2': 123.,
    'n3': 123.,
    'n4': 50.6,
    'n5': 48.9}
electron_be[54] = {
    'k' : 34561.,
    'l1': 5453.,
    'l2': 5107.,
    'l3': 4786.,
    'm1': 1148.7,
    'm2': 1002.1,
    'm3': 940.6,
    'm4': 689.,
    'm5': 676.4,
    'n1': 213.2,
    'n2': 146.7,
    'n3': 145.5,
    'n4': 69.5,
    'n5': 67.5,
    'o1': 23.3,
    'o2': 13.4,
    'o3': 12.1}
electron_be[55] = {
    'k' : 35985.,
    'l1': 5714.,
    'l2': 5359.,
    'l3': 5012.,
    'm1': 1211.,
    'm2': 1071.,
    'm3': 1003.,
    'm4': 740.5,
    'm5': 726.6,
    'n1': 231.3,
    'n2': 172.4,
    'n3': 161.3,
    'n4': 79.8,
    'n5': 77.5,
    'o1':22.7,
    'o2':14.2,
    'o3':12.1}
electron_be[56] = {
    'k' : 37441.,
    'l1': 5989.,
    'l2': 5624.,
    'l3': 5247.,
    'm1': 1293.,
    'm2': 1137.,
    'm3': 1063.,
    'm4': 795.7,
    'm5': 780.5,
    'n1': 253.5,
    'n2': 192.,
    'n3': 178.6,
    'n4': 92.6,
    'n5': 89.9,
    'o1':30.3,
    'o2':17.,
    'o3':14.8}
electron_be[57] = {
    'k' : 38925.,
    'l1': 6266.,
    'l2': 5891.,
    'l3': 5483.,
    'm1': 1362.,
    'm2': 1209.,
    'm3': 1128.,
    'm4': 853.,
    'm5': 836.,
    'n1': 274.7,
    'n2': 205.8,
    'n3': 196.,
    'n4': 105.3,
    'n5': 102.5,
    'o1':34.3,
    'o2':19.3,
    'o3':16.8}
electron_be[58] = {
    'k' : 40443.,
    'l1': 6549.,
    'l2': 6164.,
    'l3': 5723.,
    'm1': 1436.,
    'm2': 1274.,
    'm3': 1187.,
    'm4': 902.4,
    'm5': 883.8,
    'n1': 291.,
    'n2': 223.2,
    'n3': 206.5,
    'n4': 109.,
    'n6':0.1,
    'n7':0.1,
    'o1':37.8,
    'o2':19.8,
    'o3':17.}
electron_be[59] = {
    'k' : 41991.,
    'l1': 6835.,
    'l2': 6440.,
    'l3': 5964.,
    'm1': 1511.,
    'm2': 1337.,
    'm3': 1242.,
    'm4': 948.3,
    'm5': 928.8,
    'n1': 304.5,
    'n2': 236.3,
    'n3': 217.6,
    'n4': 115.1,
    'n5': 115.1,
    'n6':2.,
    'n7':2.,
    'o1':37.4,
    'o2':22.3,
    'o3':22.3}
electron_be[60] = {
    'k' : 43569.,
    'l1': 7126.,
    'l2': 6722.,
    'l3': 6208.,
    'm1': 1575.,
    'm2': 1403.,
    'm3': 1297.,
    'm4': 1003.3,
    'm5': 980.4,
    'n1': 319.2,
    'n2': 243.3,
    'n3': 224.6,
    'n4': 120.5,
    'n5': 120.5,
    'n6':1.5,
    'n7':1.5,
    'o1':37.5,
    'o2':21.1,
    'o3':21.1}
electron_be[61] = {
    'k' : 45184.,
    'l1': 7428.,
    'l2': 7013.,
    'l3': 6459.,
    'm2': 1471.,
    'm3': 1357.,
    'm4': 1052.,
    'm5': 1027.,
    'n2': 242.,
    'n3': 242.,
    'n4': 120.,
    'n5': 120.}
electron_be[62] = {
    'k' : 46834.,
    'l1': 7737.,
    'l2': 7312.,
    'l3': 6716.,
    'm1': 1723.,
    'm2': 1541.,
    'm3': 1420.,
    'm4': 1110.9,
    'm5': 1083.4,
    'n1': 347.2,
    'n2': 265.6,
    'n3': 247.4,
    'n4': 129.,
    'n5': 129.,
    'n6': 5.2,
    'n7': 5.2,
    'o1': 37.4,
    'o2': 21.3,
    'o3': 21.3}
electron_be[63] = {
    'k' : 48519.,
    'l1': 8052.,
    'l2': 7617.,
    'l3': 6977.,
    'm1': 1800.,
    'm2': 1614.,
    'm3': 1481.,
    'm4': 1158.6,
    'm5': 1127.5,
    'n1': 360.,
    'n2': 284.,
    'n3': 257.,
    'n4': 133.,
    'n5': 127.7,
    'n6': 0.,
    'n7': 0.,
    'o1': 32.,
    'o2': 22.,
    'o3': 22.}
electron_be[64] = {
    'k' : 50239.,
    'l1': 8376.,
    'l2': 7930.,
    'l3': 7243.,
    'm1': 1881.,
    'm2': 1688.,
    'm3': 1544.,
    'm4': 1221.9,
    'm5': 1189.6,
    'n1': 378.6,
    'n2': 286.,
    'n3': 271.,
    'n5': 142.6,
    'n6': 8.6,
    'n7': 8.6,
    'o1': 36.,
    'o2': 28.,
    'o3': 21.}
electron_be[65] = {
    'k' : 51996.,
    'l1': 8708.,
    'l2': 8252.,
    'l3': 7514.,
    'm1': 1968.,
    'm2': 1768.,
    'm3': 1611.,
    'm4': 1276.9,
    'm5': 1241.1,
    'n1': 396.,
    'n2': 322.4,
    'n3': 284.1,
    'n4': 150.5,
    'n5': 150.5,
    'n6': 7.7,
    'n7': 2.4,
    'o1': 45.6,
    'o2': 28.7,
    'o3': 22.6}

electron_be[66] = {
    'k' : 53789.,
    'l1': 9046.,
    'l2': 8581.,
    'l3': 7790.,
    'm1': 2047.,
    'm2': 1842.,
    'm3': 1676.,
    'm4': 1333.,
    'm5': 1292.6,
    'n1': 414.2,
    'n2': 333.5,
    'n3': 293.2,
    'n4': 153.6,
    'n5': 153.6,
    'n6': 8.,
    'n7': 4.3,
    'o1': 49.9,
    'o2': 26.3,
    'o3': 26.3}
electron_be[67] = {
    'k' : 55618.,
    'l1': 9394.,
    'l2': 8918.,
    'l3': 8071.,
    'm1': 2128.,
    'm2': 1923.,
    'm3': 1741.,
    'm4': 1392.,
    'm5': 1351.,
    'n1': 432.4,
    'n2': 343.5,
    'n3': 308.2,
    'n4': 160.,
    'n5': 160.,
    'n6': 8.6,
    'n7': 5.2,
    'o1': 49.3,
    'o2': 30.8,
    'o3': 24.1}
electron_be[68] = {
    'k' : 57486.,
    'l1': 9751.,
    'l2': 9264.,
    'l3': 8358.,
    'm1': 2207.,
    'm2': 2006.,
    'm3': 1812.,
    'm4': 1453.,
    'm5': 1409.,
    'n1': 449.8,
    'n2': 366.2,
    'n3': 320.2,
    'n4': 167.6,
    'n5': 167.6,
    'n7': 4.7,
    'o1': 50.6,
    'o2': 31.4,
    'o3': 24.7}
electron_be[69] = {
    'k' : 59390.,
    'l1': 10116.,
    'l2': 9617.,
    'l3': 8648.,
    'm1': 2307.,
    'm2': 2090.,
    'm3': 1885.,
    'm4': 1515.,
    'm5': 1468.,
    'n1': 470.9,
    'n2': 385.9,
    'n3': 332.6,
    'n4': 175.5,
    'n5': 175.5,
    'n7': 4.6,
    'o1': 54.7,
    'o2': 31.8,
    'o3': 25.}
electron_be[70] = {
    'k' : 61332.,
    'l1': 10486.,
    'l2': 9978.,
    'l3': 8944.,
    'm1': 2398.,
    'm2': 2173.,
    'm3': 1950.,
    'm4': 1576.,
    'm5': 1528.,
    'n1': 480.5,
    'n2': 388.7,
    'n3': 339.7,
    'n4': 191.2,
    'n5': 182.4,
    'n6': 2.5,
    'n7': 1.3,
    'o1': 52.,
    'o2': 30.3,
    'o3': 24.1}
electron_be[71] = {
    'k' : 63314.,
    'l1': 10870.,
    'l2': 10349.,
    'l3': 9244.,
    'm1': 2491.,
    'm2': 2264.,
    'm3': 2024.,
    'm4': 1639.,
    'm5': 1589.,
    'n1': 506.8,
    'n2': 412.4,
    'n3': 359.2,
    'n4': 206.1,
    'n5': 196.3,
    'n6': 8.9,
    'n7': 7.5,
    'o1': 57.3,
    'o2': 33.6,
    'o3': 26.7}
electron_be[72] = {
    'k' : 65351.,
    'l1': 11271.,
    'l2': 10739.,
    'l3': 9561.,
    'm1': 2601.,
    'm2': 2365.,
    'm3': 2108.,
    'm4': 1716.,
    'm5': 1662.,
    'n1': 538.,
    'n2': 438.2,
    'n3': 380.7,
    'n4': 220.,
    'n5': 211.5,
    'n6': 15.9,
    'n7': 14.2,
    'o1': 64.2,
    'o2': 38.,
    'o3': 29.9}
electron_be[73] = {
    'k' : 67416.,
    'l1': 11682.,
    'l2': 11136.,
    'l3': 9881.,
    'm1': 2708.,
    'm2': 2469.,
    'm3': 2194.,
    'm4': 1793.,
    'm5': 1735.,
    'n1': 563.4,
    'n2': 463.4,
    'n3': 400.9,
    'n4': 237.9,
    'n5': 226.4,
    'n6': 23.5,
    'n7': 21.6,
    'o1': 69.7,
    'o2': 42.2,
    'o3': 32.7}
electron_be[74] = {
    'k' : 69525.,
    'l1': 12100.,
    'l2': 11544.,
    'l3': 10207.,
    'm1': 2820.,
    'm2': 2575.,
    'm3': 2281.,
    'm4': 1872.,
    'm5': 1809.,
    'n1': 594.1,
    'n2': 490.4,
    'n3': 423.6,
    'n4': 255.9,
    'n5': 243.5,
    'n6': 33.6,
    'n7': 31.4,
    'o1': 75.6,
    'o2': 45.3,
    'o3': 36.8}
electron_be[75] = {
    'k' : 71676.,
    'l1': 12527.,
    'l2': 11959.,
    'l3': 10535.,
    'm1': 2932.,
    'm2': 2682.,
    'm3': 2367.,
    'm4': 1949.,
    'm5': 1883.,
    'n1': 625.4,
    'n2': 518.7,
    'n3': 446.8,
    'n4': 273.9,
    'n5': 260.5,
    'n6': 42.9,
    'n7': 40.5,
    'o1': 83.,
    'o2': 45.6,
    'o3': 34.6}
electron_be[76] = {
    'k' : 73871.,
    'l1': 12968.,
    'l2': 12385.,
    'l3': 10871.,
    'm1': 3049.,
    'm2': 2792.,
    'm3': 2457.,
    'm4': 2031.,
    'm5': 1960.,
    'n1': 658.2,
    'n2': 549.1,
    'n3': 470.7,
    'n4': 293.1,
    'n5': 278.5,
    'n6': 53.4,
    'n7': 50.7,
    'o1': 84.,
    'o2': 58.,
    'o3': 44.5}
electron_be[77] = {
    'k' : 76111.,
    'l1': 13419.,
    'l2': 12824.,
    'l3': 11215.,
    'm1': 3174.,
    'm2': 2909.,
    'm3': 2551.,
    'm4': 2116.,
    'm5': 2040.,
    'n1': 691.1,
    'n2': 577.8,
    'n3': 495.8,
    'n4': 311.9,
    'n5': 296.3,
    'n6': 63.8,
    'n7': 60.8,
    'o1': 95.2,
    'o2': 63.,
    'o3': 48.}
electron_be[78] = {
    'k' : 78395.,
    'l1': 13880.,
    'l2': 13273.,
    'l3': 11564.,
    'm1': 3296.,
    'm2': 3027.,
    'm3': 2645.,
    'm4': 2202.,
    'm5': 2122.,
    'n1': 725.4,
    'n2': 609.1,
    'n3': 519.4,
    'n4': 331.6,
    'n5': 314.6,
    'n6': 74.5,
    'n7': 71.2,
    'o1': 101.7,
    'o2': 65.3,
    'o3': 51.7}
electron_be[79] = {
    'k' : 80725.,
    'l1': 14353.,
    'l2': 13273.,
    'l3': 11919.,
    'm1': 3425.,
    'm2': 3148.,
    'm3': 2743.,
    'm4': 2291.,
    'm5': 2206.,
    'n1': 762.1,
    'n2': 642.7,
    'n3': 546.3,
    'n4': 353.2,
    'n5': 335.1,
    'n6': 87.6,
    'n7': 84.,
    'o1': 107.2,
    'o2': 74.2,
    'o3': 57.2}
electron_be[80] = {
    'k' : 83102.,
    'l1': 14839.,
    'l2': 14209.,
    'l3': 12284.,
    'm1': 3562.,
    'm2': 3279.,
    'm3': 2847.,
    'm4': 2385.,
    'm5': 2295.,
    'n1': 802.2,
    'n2': 680.2,
    'n3': 576.6,
    'n4': 378.2,
    'n5': 358.8,
    'n6': 104.,
    'n7': 99.9,
    'o1': 127.,
    'o2': 83.1,
    'o3': 64.5,
    'o4': 9.6,
    'o5': 7.8}
electron_be[81] = {
    'k' : 85530.,
    'l1': 15347.,
    'l2': 14698.,
    'l3': 12658.,
    'm1': 3704.,
    'm2': 3416.,
    'm3': 2957.,
    'm4': 2485.,
    'm5': 2389.,
    'n1': 846.2,
    'n2': 720.5,
    'n3': 609.5,
    'n4': 405.7,
    'n5': 385.,
    'n6': 122.2,
    'n7': 117.8,
    'o1': 136.,
    'o2': 94.6,
    'o3': 73.5,
    'o4': 14.7,
    'o5': 12.5}
electron_be[82] = {
    'k' : 88005.,
    'l1': 15861.,
    'l2': 15200.,
    'l3': 13035.,
    'm1': 3851.,
    'm2': 3554.,
    'm3': 3066.,
    'm4': 2586.,
    'm5': 2484.,
    'n1': 891.8,
    'n2': 761.9,
    'n3': 643.5,
    'n4': 434.3,
    'n5': 412.2,
    'n6': 141.7,
    'n7': 136.9,
    'o1': 147.,
    'o2': 106.4,
    'o3': 83.3,
    'o4': 20.7,
    'o5': 18.1}
electron_be[83] = {
    'k' : 90524.,
    'l1': 16388.,
    'l2': 15711.,
    'l3': 13419.,
    'm1': 3999.,
    'm2': 3696.,
    'm3': 3177.,
    'm4': 2688.,
    'm5': 2580.,
    'n1': 939.,
    'n2': 805.2,
    'n3': 678.8,
    'n4': 464.,
    'n5': 440.1,
    'n6': 162.3,
    'n7': 157.,
    'o1': 159.3,
    'o2': 119.,
    'o3': 92.6,
    'o4': 26.9,
    'o5': 23.8}

electron_be[84] = {
    'k' : 93105.,
    'l1': 16939.,
    'l2': 16244.,
    'l3': 13814.,
    'm1': 4149.,
    'm2': 3854.,
    'm3': 3302.,
    'm4': 2798.,
    'm5': 2683.,
    'n1': 995.,
    'n2': 851.,
    'n3': 705.,
    'n4': 500.,
    'n5': 473.,
    'n6': 184.,
    'n7': 184.,
    'o1': 177.,
    'o2': 132.,
    'o3': 104.,
    'o4': 31.,
    'o5': 31.}
electron_be[85] = {
    'k' : 95730.,
    'l1': 17493.,
    'l2': 16785.,
    'l3': 14214.,
    'm1': 4317.,
    'm2': 4008.,
    'm3': 3426.,
    'm4': 2909.,
    'm5': 2787.,
    'n1': 1042.,
    'n2': 886.,
    'n3': 740.,
    'n4': 533.,
    'n5': 507.,
    'n6': 210.,
    'n7': 210.,
    'o1': 195.,
    'o2': 148.,
    'o3': 115.,
    'o4': 40.,
    'o5': 40.}
electron_be[86] = {
    'k' : 98404.,
    'l1': 18049.,
    'l2': 17337.,
    'l3': 14619.,
    'm1': 4482.,
    'm2': 4159.,
    'm3': 3538.,
    'm4': 3022.,
    'm5': 2892.,
    'n1': 1097.,
    'n2': 929.,
    'n3': 768.,
    'n4': 567.,
    'n5': 541.,
    'n6': 238.,
    'n7': 238.,
    'o1': 214.,
    'o2': 164.,
    'o3': 127.,
    'o4': 48.,
    'o5': 48.,
    'p1': 26.}
electron_be[87] = {
    'k' : 101137.,
    'l1': 18639.,
    'l2': 17907.,
    'l3': 15031.,
    'm1': 4652.,
    'm2': 4327.,
    'm3': 3663.,
    'm4': 3136.,
    'm5': 3000.,
    'n1': 1153.,
    'n2': 980.,
    'n3': 810.,
    'n4': 603.,
    'n5': 577.,
    'n6': 268.,
    'n7': 268.,
    'o1': 234.,
    'o2': 182.,
    'o3': 140.,
    'o4': 58.,
    'o5': 58.,
    'p1': 34.,
    'p2': 15.,
    'p3': 15.}
electron_be[88] = {
    'k' : 103922.,
    'l1': 19237.,
    'l2': 18484.,
    'l3': 15444.,
    'm1': 4822.,
    'm2': 4490.,
    'm3': 3792.,
    'm4': 3248.,
    'm5': 3105.,
    'n1': 1208.,
    'n2': 1058.,
    'n3': 879.,
    'n4': 636.,
    'n5': 603.,
    'n6': 299.,
    'n7': 299.,
    'o1': 254.,
    'o2': 200.,
    'o3': 153.,
    'o4': 68.,
    'o5': 68.,
    'p1': 44.,
    'p2': 19.,
    'p3': 19.}
electron_be[89] = {
    'k' : 106755.,
    'l1': 19840.,
    'l2': 19083.,
    'l3': 15871.,
    'm1': 5002.,
    'm2': 4656.,
    'm3': 3909.,
    'm4': 3370.,
    'm5': 3219.,
    'n1': 1269.,
    'n2': 1080.,
    'n3': 890.,
    'n4': 675.,
    'n5': 639.,
    'n6': 319.,
    'n7': 319.,
    'o1': 272.,
    'o2': 215.,
    'o3': 167.,
    'o4': 80.,
    'o5': 80.}
electron_be[90] = {
    'k' : 109651.,
    'l1': 20472.,
    'l2': 19693.,
    'l3': 16300.,
    'm1': 5182.,
    'm2': 4830.,
    'm3': 4046.,
    'm4': 3491.,
    'm5': 3332.,
    'n1': 1330.,
    'n2': 1168.,
    'n3': 966.4,
    'n4': 712.1,
    'n5': 675.2,
    'n6': 342.4,
    'n7': 333.1,
    'o1': 290.,
    'o2': 229.,
    'o3': 182.,
    'o4': 92.5,
    'o5': 85.4,
    'p1': 41.4,
    'p2': 24.5,
    'p3': 16.6}
electron_be[91] = {
    'k' : 112601.,
    'l1': 21105.,
    'l2': 20314.,
    'l3': 16733.,
    'm1': 5367.,
    'm2': 5001.,
    'm3': 4174.,
    'm4': 3611.,
    'm5': 3442.,
    'n1': 1387.,
    'n2': 1224.,
    'n3': 1007.,
    'n4': 743.,
    'n5': 708.,
    'n6': 371.,
    'n7': 360.,
    'o1': 310.,
    'o2': 232.,
    'o3': 232.,
    'o4': 94.,
    'o5': 94.}
electron_be[92] = {
    'k' : 115606.,
    'l1': 21757.,
    'l2': 20948.,
    'l3': 17166.,
    'm1': 5548.,
    'm2': 5182.,
    'm3': 4303.,
    'm4': 3728.,
    'm5': 3552.,
    'n1': 1439.,
    'n2': 1271.,
    'n3': 1043.,
    'n4': 778.3,
    'n5': 736.2,
    'n6': 388.2,
    'n7': 377.4,
    'o1': 321.,
    'o2': 257.,
    'o3': 192.,
    'o4': 102.8,
    'o5': 94.2,
    'p1': 43.9,
    'p2': 26.8,
    'p3': 16.8}
